# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.dom.events
from __future__ import annotations
import typing
from abc import abstractmethod
from ....uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ....util.time import Time as Time_604e0855
    from .x_event_target import XEventTarget as XEventTarget_36420f4b
    from com.sun.star.xml.dom.events.PhaseType import PhaseTypeProto  # type: ignore

class XEvent(XInterface_8f010a43):
    """

    See Also:
        `API XEvent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events_1_1XEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.dom.events'
    __ooo_full_ns__: str = 'com.sun.star.xml.dom.events.XEvent'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.dom.events.XEvent'

    @abstractmethod
    def getBubbles(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def getCancelable(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def getCurrentTarget(self) -> XEventTarget_36420f4b:
        """
        """
        ...
    @abstractmethod
    def getEventPhase(self) -> PhaseTypeProto:
        """
        """
        ...
    @abstractmethod
    def getTarget(self) -> XEventTarget_36420f4b:
        """
        """
        ...
    @abstractmethod
    def getTimeStamp(self) -> Time_604e0855:
        """
        """
        ...
    @abstractmethod
    def getType(self) -> str:
        """
        """
        ...
    @abstractmethod
    def initEvent(self, eventTypeArg: str, canBubbleArg: bool, cancelableArg: bool) -> None:
        """
        """
        ...
    @abstractmethod
    def preventDefault(self) -> None:
        """
        """
        ...
    @abstractmethod
    def stopPropagation(self) -> None:
        """
        """
        ...

__all__ = ['XEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .property import Property as Property_8f4e0a76

class XProperty(XInterface_8f010a43):
    """
    Is implemented by objects that also are a property of some other object.
    
    Provides access to traits of this object that would otherwise only be available from a containing XPropertySet via its XPropertySetInfo.

    See Also:
        `API XProperty <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XProperty.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.XProperty'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.beans.XProperty'

    @abstractmethod
    def getAsProperty(self) -> Property_8f4e0a76:
        """
        """
        ...

__all__ = ['XProperty']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.table
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from com.sun.star.table.CellContentType import CellContentTypeProto  # type: ignore

class XCell(XInterface_8f010a43):
    """
    provides methods to access the contents of a cell in a table.

    See Also:
        `API XCell <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1table_1_1XCell.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.XCell'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.table.XCell'

    @abstractmethod
    def getError(self) -> int:
        """
        returns the error value of the cell.
        
        If the cell does not contain a formula, the error is always zero.
        """
        ...
    @abstractmethod
    def getFormula(self) -> str:
        """
        returns the formula string of a cell.
        
        Even if the cell does not contain a formula, an assignment of this attribute's value to another cell's formula attribute would create the same cell content. This is because this attribute contains the original text value of a string cell. The value of a value cell will be formatted using the number format's default format or the formula string, including \"=\", of a formula cell.
        """
        ...
    @abstractmethod
    def getType(self) -> CellContentTypeProto:
        """
        returns the type of the cell.
        """
        ...
    @abstractmethod
    def getValue(self) -> float:
        """
        returns the floating point value of the cell.
        
        For a value cell the value is returned, for a string cell zero is returned and for a formula cell the result value of a formula is returned.
        """
        ...
    @abstractmethod
    def setFormula(self, aFormula: str) -> None:
        """
        sets a formula into the cell.
        
        When assigned, the string will be interpreted and a value, text or formula cell is created, depending on the text and the number format.
        """
        ...
    @abstractmethod
    def setValue(self, nValue: float) -> None:
        """
        sets a floating point value into the cell.
        
        After a call to this method the type of the cell is CellContentType.VALUE.
        """
        ...

__all__ = ['XCell']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .hatch_style import HatchStyle as HatchStyle_bcfe0bed
from ..util.color import Color as Color_68e908c5


class Hatch(object):
    """
    Struct Class

    This struct defines the appearance of a hatch.
    
    A hatch is a texture made of straight lines.

    See Also:
        `API Hatch <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1Hatch.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.Hatch'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.Hatch'
    """Literal Constant ``com.sun.star.drawing.Hatch``"""

    def __init__(self, Style: typing.Optional[HatchStyle_bcfe0bed] = HatchStyle_bcfe0bed.SINGLE, Color: typing.Optional[Color_68e908c5] = Color_68e908c5(0), Distance: typing.Optional[int] = 0, Angle: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Style (HatchStyle, optional): Style value.
            Color (Color, optional): Color value.
            Distance (int, optional): Distance value.
            Angle (int, optional): Angle value.
        """
        super().__init__()

        if isinstance(Style, Hatch):
            oth: Hatch = Style
            self.Style = oth.Style
            self.Color = oth.Color
            self.Distance = oth.Distance
            self.Angle = oth.Angle
            return

        kargs = {
            "Style": Style,
            "Color": Color,
            "Distance": Distance,
            "Angle": Angle,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._style = kwargs["Style"]
        self._color = kwargs["Color"]
        self._distance = kwargs["Distance"]
        self._angle = kwargs["Angle"]


    @property
    def Style(self) -> HatchStyle_bcfe0bed:
        """
        The HatchStyle defines the kind of lines used to draw this hatch.
        """
        return self._style

    @Style.setter
    def Style(self, value: HatchStyle_bcfe0bed) -> None:
        self._style = value

    @property
    def Color(self) -> Color_68e908c5:
        """
        This is the color of the hatch lines.
        """
        return self._color

    @Color.setter
    def Color(self, value: Color_68e908c5) -> None:
        self._color = value

    @property
    def Distance(self) -> int:
        """
        This is the distance between the lines in the hatch.
        """
        return self._distance

    @Distance.setter
    def Distance(self, value: int) -> None:
        self._distance = value

    @property
    def Angle(self) -> int:
        """
        You can rotate the lines of the hatch with this angle.
        
        Specified in tenths of a degree.
        """
        return self._angle

    @Angle.setter
    def Angle(self, value: int) -> None:
        self._angle = value


__all__ = ['Hatch']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..task.classified_interaction_request import ClassifiedInteractionRequest as ClassifiedInteractionRequest_9f72121b
from ..uno.x_interface import XInterface as XInterface_8f010a43
from ..task.interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7
from ..ucb.x_content import XContent as XContent_79db0975

class DocumentSaveRequest(ClassifiedInteractionRequest_9f72121b):
    """
    Exception Class

    an error specifying the lack of a document name
    
    Usually thrown if someone tries to save a document which hasn't a name yet.
    
    **since**
    
        OOo 2.0

    See Also:
        `API DocumentSaveRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1sdb_1_1DocumentSaveRequest.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DocumentSaveRequest'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.sdb.DocumentSaveRequest'
    __pyunostruct__: str = 'com.sun.star.sdb.DocumentSaveRequest'

    typeName: str = 'com.sun.star.sdb.DocumentSaveRequest'
    """Literal Constant ``com.sun.star.sdb.DocumentSaveRequest``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, Classification: typing.Optional[InteractionClassification_6c4d10e7] = InteractionClassification_6c4d10e7.ERROR, Content: typing.Optional[XContent_79db0975] = None, Name: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            Content (XContent, optional): Content value.
            Name (str, optional): Name value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "Classification": Classification,
            "Content": Content,
            "Name": Name,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._content = kwargs["Content"]
        self._name = kwargs["Name"]
        inst_keys = ('Content', 'Name')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def Content(self) -> XContent_79db0975:
        """
        specifies the content where the document should save inside.
        
        Somebody handling the request could, e.g., use the content as root content to display the hierarchy of the sub contents.
        """
        return self._content
    
    @Content.setter
    def Content(self, value: XContent_79db0975) -> None:
        self._content = value

    @property
    def Name(self) -> str:
        """
        The default name of the document, may be empty.
        """
        return self._name
    
    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value


__all__ = ['DocumentSaveRequest']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.component
from __future__ import annotations
import typing
from abc import abstractproperty
from ..form_components import FormComponents as FormComponents_c8e60c76
from ..form_control_model import FormControlModel as FormControlModel_e2990d22
from ..x_grid_column_factory import XGridColumnFactory as XGridColumnFactory_fbb70de0
from ..x_reset import XReset as XReset_71670917
from ...view.x_selection_supplier import XSelectionSupplier as XSelectionSupplier_fed20e15
if typing.TYPE_CHECKING:
    from ...awt.font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from ...util.color import Color as Color_68e908c5

class GridControl(FormComponents_c8e60c76, FormControlModel_e2990d22, XGridColumnFactory_fbb70de0, XReset_71670917, XSelectionSupplier_fed20e15):
    """
    Service Class

    specifies a model for a control which can display form data in a table-like way.
    
    In opposite to other form controls, grid controls do not only display the single current value of a column they are bound to. Moreover, they do display not only the current row of the form, but all rows (at least potentially, limited by the control size, of course).
    
    The table rows in a grid control correspond to the rows in the DataForm the control belongs to, and the columns correspond to single columns of the form's row set.
    
    Columns of a grid control are modeled by own objects, too. They are very similar to usual com.sun.star.form.DataAwareControlModels modeling other \"single-value\" controls, but they are not described as own services. Instead, they need to be created using the com.sun.star.form.XGridColumnFactory interface.
    
    **since**
    
        OOo 2.0

    See Also:
        `API GridControl <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1GridControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.component'
    __ooo_full_ns__: str = 'com.sun.star.form.component.GridControl'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Border(self) -> int:
        """
        returns the border style of the control.
        """
        ...

    @abstractproperty
    def BorderColor(self) -> int:
        """
        specifies the color of the border, if present
        
        Not every border style (see Border) may support coloring. For instance, usually a border with 3D effect will ignore the BorderColor setting.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether the control is enabled or disabled.
        """
        ...

    @abstractproperty
    def FontDescriptor(self) -> FontDescriptor_bc110c0a:
        """
        contains the font attributes of the text in the control.
        """
        ...

    @abstractproperty
    def RowHeight(self) -> int:
        """
        specifies the height of a row of the grid.
        
        If the value is set to NULL, the height is determined automatically according to the current font used.
        """
        ...

    @abstractproperty
    def Tabstop(self) -> bool:
        """
        determines whether the control can be reached by the tabulator key.
        """
        ...

    @abstractproperty
    def TextColor(self) -> Color_68e908c5:
        """
        specifies the text color (RGB) of the control.
        """
        ...


__all__ = ['GridControl']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..document.office_document import OfficeDocument as OfficeDocument_fecd0df2
from .x_draw_page_duplicator import XDrawPageDuplicator as XDrawPageDuplicator_37bd0f6e
from .x_draw_pages_supplier import XDrawPagesSupplier as XDrawPagesSupplier_29650f1e
from .x_layer_supplier import XLayerSupplier as XLayerSupplier_f0da0d9d
from .x_master_pages_supplier import XMasterPagesSupplier as XMasterPagesSupplier_49bb0ffc
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
from ..style.x_style_families_supplier import XStyleFamiliesSupplier as XStyleFamiliesSupplier_4c5a1020
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..i18n.x_forbidden_characters import XForbiddenCharacters as XForbiddenCharacters_df60e2d
    from ..lang.locale import Locale as Locale_70d308fa

class GenericDrawingDocument(OfficeDocument_fecd0df2, XPropertySet_bc180bfa, XDrawPageDuplicator_37bd0f6e, XDrawPagesSupplier_29650f1e, XLayerSupplier_f0da0d9d, XMasterPagesSupplier_49bb0ffc, XMultiServiceFactory_191e0eb6, XStyleFamiliesSupplier_4c5a1020):
    """
    Service Class

    specifies a document which consists of multiple pages with drawings.
    
    Because its function is needed more than once, it's defined as generic one.

    See Also:
        `API GenericDrawingDocument <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1GenericDrawingDocument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.GenericDrawingDocument'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CharLocale(self) -> Locale_70d308fa:
        """
        contains the identifier of the default locale of the document.
        """
        ...

    @abstractproperty
    def ForbiddenCharacters(self) -> XForbiddenCharacters_df60e2d:
        """
        This property gives the XForbiddenCharacters.
        """
        ...

    @abstractproperty
    def TabStop(self) -> int:
        """
        This property specifies the length between the default tab stops inside text in this document in 1/100th mm.
        """
        ...

    @abstractproperty
    def VisibleArea(self) -> Rectangle_84b109e9:
        """
        if this document is an OLE client, this is the current visible area in 100th mm
        """
        ...


__all__ = ['GenericDrawingDocument']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class HoriOrientationFormat(object):
    """
    Struct Class

    describes the horizontal orientation of an object.
    
    If HorizontalOrientation == HORI_NONE, then the value \"XPos\" describes the distance from the left border of the context. Otherwise \"XPos\" is ignored.
    
    The following flags are used to adapt the position of the object to odd and even pages. If \"PositionToggle\" is set, then the horizontal position is mirrored.

    See Also:
        `API HoriOrientationFormat <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1text_1_1HoriOrientationFormat.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.HoriOrientationFormat'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.text.HoriOrientationFormat'
    """Literal Constant ``com.sun.star.text.HoriOrientationFormat``"""

    def __init__(self, XPos: typing.Optional[int] = 0, HorizontalOrientation: typing.Optional[int] = 0, HorizontalRelation: typing.Optional[int] = 0, PositionToggle: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            XPos (int, optional): XPos value.
            HorizontalOrientation (int, optional): HorizontalOrientation value.
            HorizontalRelation (int, optional): HorizontalRelation value.
            PositionToggle (bool, optional): PositionToggle value.
        """
        super().__init__()

        if isinstance(XPos, HoriOrientationFormat):
            oth: HoriOrientationFormat = XPos
            self.XPos = oth.XPos
            self.HorizontalOrientation = oth.HorizontalOrientation
            self.HorizontalRelation = oth.HorizontalRelation
            self.PositionToggle = oth.PositionToggle
            return

        kargs = {
            "XPos": XPos,
            "HorizontalOrientation": HorizontalOrientation,
            "HorizontalRelation": HorizontalRelation,
            "PositionToggle": PositionToggle,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._x_pos = kwargs["XPos"]
        self._horizontal_orientation = kwargs["HorizontalOrientation"]
        self._horizontal_relation = kwargs["HorizontalRelation"]
        self._position_toggle = kwargs["PositionToggle"]


    @property
    def XPos(self) -> int:
        """
        contains the distance from the left border.
        
        Only valid if the property HorizontalOrientation contains the value HORI_NONE.
        """
        return self._x_pos

    @XPos.setter
    def XPos(self, value: int) -> None:
        self._x_pos = value

    @property
    def HorizontalOrientation(self) -> int:
        """
        determines the horizontal alignment of an object.
        
        The values refer to com.sun.star.HoriOrientation.
        """
        return self._horizontal_orientation

    @HorizontalOrientation.setter
    def HorizontalOrientation(self, value: int) -> None:
        self._horizontal_orientation = value

    @property
    def HorizontalRelation(self) -> int:
        """
        determines the reference position of the horizontal alignment.
        """
        return self._horizontal_relation

    @HorizontalRelation.setter
    def HorizontalRelation(self, value: int) -> None:
        self._horizontal_relation = value

    @property
    def PositionToggle(self) -> bool:
        """
        determines if the orientation toggles between left and right pages.
        """
        return self._position_toggle

    @PositionToggle.setter
    def PositionToggle(self, value: bool) -> None:
        self._position_toggle = value


__all__ = ['HoriOrientationFormat']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from .x_dictionary import XDictionary as XDictionary_fea70de3
    from .x_dictionary_list_event_listener import XDictionaryListEventListener as XDictionaryListEventListener_279814c7
    from com.sun.star.linguistic2.DictionaryType import DictionaryTypeProto  # type: ignore

class XDictionaryList(XInterface_8f010a43):
    """
    is used to manage and maintain a list of dictionaries.
    
    A dictionary-list may be given to a spell checker or hyphenator service implementation on their creation in order to supply a set of dictionaries and additional information to be used for those purposes.

    See Also:
        `API XDictionaryList <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionaryList.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XDictionaryList'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XDictionaryList'

    @abstractmethod
    def addDictionary(self, xDictionary: XDictionary_fea70de3) -> bool:
        """
        adds a dictionary to the list.
        
        Additionally, the dictionary-list will add itself to the list of dictionary event listeners of that dictionary.
        """
        ...
    @abstractmethod
    def addDictionaryListEventListener(self, xListener: XDictionaryListEventListener_279814c7, bReceiveVerbose: bool) -> bool:
        """
        adds an entry to the list of dictionary-list event listeners.
        
        On dictionary-list events, each entry in the listener list will be notified via a call to com.sun.star.linguistic2.XDictionaryListEventListener.processDictionaryListEvent().
        """
        ...
    @abstractmethod
    def beginCollectEvents(self) -> int:
        """
        increases request level for event buffering by one.
        
        The request level for event buffering is an integer counter that is initially set to 0. As long as the request level is not 0, events will be buffered until the next flushing of the buffer.
        """
        ...
    @abstractmethod
    def createDictionary(self, aName: str, aLocale: Locale_70d308fa, eDicType: DictionaryTypeProto, aURL: str) -> XDictionary_fea70de3:
        """
        creates a new dictionary.
        """
        ...
    @abstractmethod
    def endCollectEvents(self) -> int:
        """
        flushes the event buffer and decreases the request level for event buffering by one.
        
        There should be one matching endCollectEvents call for every beginCollectEvents call. Usually you will group these around some code where you do not wish to get notified of every single event.
        """
        ...
    @abstractmethod
    def flushEvents(self) -> int:
        """
        notifies the listeners of all buffered events and then clears that buffer.
        """
        ...
    @abstractmethod
    def getCount(self) -> int:
        """
        """
        ...
    @abstractmethod
    def getDictionaries(self) -> typing.Tuple[XDictionary_fea70de3, ...]:
        """
        """
        ...
    @abstractmethod
    def getDictionaryByName(self, aDictionaryName: str) -> XDictionary_fea70de3:
        """
        searches the list for a dictionary with a given name.
        """
        ...
    @abstractmethod
    def removeDictionary(self, xDictionary: XDictionary_fea70de3) -> bool:
        """
        removes a single dictionary from the list.
        
        If the dictionary is still active, it will be deactivated first. The dictionary-list will remove itself from the list of dictionary event listeners of the dictionary.
        """
        ...
    @abstractmethod
    def removeDictionaryListEventListener(self, xListener: XDictionaryListEventListener_279814c7) -> bool:
        """
        removes an entry from the list of dictionary-list event listeners.
        """
        ...

__all__ = ['XDictionaryList']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.logging.console_handler import ConsoleHandler as ConsoleHandler
from ...lo.logging.csv_log_formatter import CsvLogFormatter as CsvLogFormatter
from ...lo.logging.file_handler import FileHandler as FileHandler
from ...lo.logging.log_level import LogLevel as LogLevel
from ...lo.logging.log_record import LogRecord as LogRecord
from ...lo.logging.logger_pool import LoggerPool as LoggerPool
from ...lo.logging.plain_text_formatter import PlainTextFormatter as PlainTextFormatter
from ...lo.logging.simple_text_formatter import SimpleTextFormatter as SimpleTextFormatter
from ...lo.logging.x_console_handler import XConsoleHandler as XConsoleHandler
from ...lo.logging.x_csv_log_formatter import XCsvLogFormatter as XCsvLogFormatter
from ...lo.logging.x_log_formatter import XLogFormatter as XLogFormatter
from ...lo.logging.x_log_handler import XLogHandler as XLogHandler
from ...lo.logging.x_logger import XLogger as XLogger
from ...lo.logging.x_logger_pool import XLoggerPool as XLoggerPool



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..geometry.integer_size2_d import IntegerSize2D as IntegerSize2D_f2690d53
    from ..geometry.real_bezier_segment2_d import RealBezierSegment2D as RealBezierSegment2D_4a970fa2
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78
    from ..geometry.real_size2_d import RealSize2D as RealSize2D_ca1a0c09
    from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
    from .x_bezier_poly_polygon2_d import XBezierPolyPolygon2D as XBezierPolyPolygon2D_6ba01081
    from .x_bitmap import XBitmap as XBitmap_b1b70b7b
    from .x_buffer_controller import XBufferController as XBufferController_3a970f9c
    from .x_color_space import XColorSpace as XColorSpace_e3940d09
    from .x_line_poly_polygon2_d import XLinePolyPolygon2D as XLinePolyPolygon2D_4a270fa8
    from .x_volatile_bitmap import XVolatileBitmap as XVolatileBitmap_1ca40ebb

class XGraphicDevice(XInterface_8f010a43):
    """
    This interface provides access to a graphic device, such as a printer, or a screen device.
    
    Every canvas (
    
    For a typical windowing system, the graphic device is equivalent to a distinct OS window, with its own clipped output area, fullscreen and double-buffering attributes. That is, even if one can have multiple canvases per system window, they all share the same graphic device and thus e.g. fullscreen state. If the OS restrictions are in such a way that fullscreen or double-buffering is screen-exclusive, i.e. that per screen, only one object can have this state, it might even be that all windows on the screen share a common graphic device.

    See Also:
        `API XGraphicDevice <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XGraphicDevice.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XGraphicDevice'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XGraphicDevice'

    @abstractmethod
    def createCompatibleAlphaBitmap(self, size: IntegerSize2D_f2690d53) -> XBitmap_b1b70b7b:
        """
        Create a bitmap with alpha channel whose memory layout and sample model is compatible to the graphic device.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def createCompatibleBezierPolyPolygon(self, points: typing.Tuple[typing.Tuple[RealBezierSegment2D_4a970fa2, ...], ...]) -> XBezierPolyPolygon2D_6ba01081:
        """
        Create a Bezier poly-polygon which can internally use device-optimized representations already.
        """
        ...
    @abstractmethod
    def createCompatibleBitmap(self, size: IntegerSize2D_f2690d53) -> XBitmap_b1b70b7b:
        """
        Create a bitmap whose memory layout and sample model is compatible to the graphic device.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def createCompatibleLinePolyPolygon(self, points: typing.Tuple[typing.Tuple[RealPoint2D_d6e70c78, ...], ...]) -> XLinePolyPolygon2D_4a270fa8:
        """
        Create a line poly-polygon which can internally use device-optimized representations already.
        """
        ...
    @abstractmethod
    def createVolatileAlphaBitmap(self, size: IntegerSize2D_f2690d53) -> XVolatileBitmap_1ca40ebb:
        """
        Create a volatile bitmap with alpha channel that is usable with this graphic device.
        
        A volatile bitmap's difference in comparison to a plain bitmap (e.g. generated via createCompatibleBitmap()) is the fact that its content might vanish at any point in time (making any operation with them produce a VolatileContentDestroyedException). The benefit, on the other hand, is that they might be easy to hardware-accelerate on certain platforms, without the need to keep a safety copy of the content internally.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def createVolatileBitmap(self, size: IntegerSize2D_f2690d53) -> XVolatileBitmap_1ca40ebb:
        """
        Create a volatile bitmap that is usable with this graphic device.
        
        A volatile bitmap's difference in comparison to a plain bitmap (e.g. generated via createCompatibleBitmap()) is the fact that its content might vanish at any point in time (making any operation with them produce a VolatileContentDestroyedException). The benefit, on the other hand, is that they might be easy to hardware-accelerate on certain platforms, without the need to keep a safety copy of the content internally.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def enterFullScreenMode(self, bEnter: bool) -> bool:
        """
        Enter or leave the fullscreen mode, if possible.
        
        The return value denotes the success of the operation.
        """
        ...
    @abstractmethod
    def getBufferController(self) -> XBufferController_3a970f9c:
        """
        Query the controller for multi buffering functionality on this graphic device.
        
        If there is no such functionality available, the NULL reference is returned.
        """
        ...
    @abstractmethod
    def getDeviceColorSpace(self) -> XColorSpace_e3940d09:
        """
        Query the color space interface for this graphic device.
        
        This is to be used when interpreting or setting device color values.
        """
        ...
    @abstractmethod
    def getParametricPolyPolygonFactory(self) -> XMultiServiceFactory_191e0eb6:
        """
        Get a reference to this device's parametric polygon factory.
        
        Available services (all canvas implementations should provide this minimal set, though are free to add more; just check the getAvailableServiceNames() on the returned interface):
        """
        ...
    @abstractmethod
    def getPhysicalResolution(self) -> RealSize2D_ca1a0c09:
        """
        Query the physical resolution of the device in pixel per millimeter.
        
        A special floating point value of +infinity here indicates \"unknown\", i.e. at the time of rendering undetermined or possibly infinite resolution along the corresponding direction.
        """
        ...
    @abstractmethod
    def getPhysicalSize(self) -> RealSize2D_ca1a0c09:
        """
        Query the physical dimensions of the device in millimeter.
        
        A special floating point value of +infinity here indicates \"unknown\", i.e. at the time of rendering undetermined or possibly infinite resolution along the corresponding direction.
        """
        ...
    @abstractmethod
    def hasFullScreenMode(self) -> bool:
        """
        Tells whether this graphic device has a full screen mode, i.e.
        
        whether a window can cover the whole screen exclusively.
        """
        ...

__all__ = ['XGraphicDevice']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.ui.action_trigger import ActionTrigger as ActionTrigger
with suppress(ImportError):
    from ...dyn.ui.action_trigger_container import ActionTriggerContainer as ActionTriggerContainer
with suppress(ImportError):
    from ...dyn.ui.action_trigger_separator import ActionTriggerSeparator as ActionTriggerSeparator
with suppress(ImportError):
    from ...dyn.ui.action_trigger_separator_type import ActionTriggerSeparatorType as ActionTriggerSeparatorType
with suppress(ImportError):
    from ...dyn.ui.action_trigger_separator_type import ActionTriggerSeparatorTypeEnum as ActionTriggerSeparatorTypeEnum
with suppress(ImportError):
    from ...dyn.ui.address_book_source_dialog import AddressBookSourceDialog as AddressBookSourceDialog
with suppress(ImportError):
    from ...dyn.ui.configurable_ui_element import ConfigurableUIElement as ConfigurableUIElement
with suppress(ImportError):
    from ...dyn.ui.configuration_event import ConfigurationEvent as ConfigurationEvent
with suppress(ImportError):
    from ...dyn.ui.context_change_event_multiplexer import ContextChangeEventMultiplexer as ContextChangeEventMultiplexer
with suppress(ImportError):
    from ...dyn.ui.context_change_event_object import ContextChangeEventObject as ContextChangeEventObject
with suppress(ImportError):
    from ...dyn.ui.context_menu_execute_event import ContextMenuExecuteEvent as ContextMenuExecuteEvent
with suppress(ImportError):
    from ...dyn.ui.context_menu_interceptor_action import ContextMenuInterceptorAction as ContextMenuInterceptorAction
with suppress(ImportError):
    from ...dyn.ui.docking_area import DockingArea as DockingArea
with suppress(ImportError):
    from ...dyn.ui.document_accelerator_configuration import DocumentAcceleratorConfiguration as DocumentAcceleratorConfiguration
with suppress(ImportError):
    from ...dyn.ui.global_accelerator_configuration import GlobalAcceleratorConfiguration as GlobalAcceleratorConfiguration
with suppress(ImportError):
    from ...dyn.ui.image_manager import ImageManager as ImageManager
with suppress(ImportError):
    from ...dyn.ui.image_type import ImageType as ImageType
with suppress(ImportError):
    from ...dyn.ui.image_type import ImageTypeEnum as ImageTypeEnum
with suppress(ImportError):
    from ...dyn.ui.item_descriptor import ItemDescriptor as ItemDescriptor
with suppress(ImportError):
    from ...dyn.ui.item_style import ItemStyle as ItemStyle
with suppress(ImportError):
    from ...dyn.ui.item_style import ItemStyleEnum as ItemStyleEnum
with suppress(ImportError):
    from ...dyn.ui.item_type import ItemType as ItemType
with suppress(ImportError):
    from ...dyn.ui.item_type import ItemTypeEnum as ItemTypeEnum
with suppress(ImportError):
    from ...dyn.ui.layout_size import LayoutSize as LayoutSize
with suppress(ImportError):
    from ...dyn.ui.module_accelerator_configuration import ModuleAcceleratorConfiguration as ModuleAcceleratorConfiguration
with suppress(ImportError):
    from ...dyn.ui.module_ui_category_description import ModuleUICategoryDescription as ModuleUICategoryDescription
with suppress(ImportError):
    from ...dyn.ui.module_ui_command_description import ModuleUICommandDescription as ModuleUICommandDescription
with suppress(ImportError):
    from ...dyn.ui.module_ui_configuration_manager import ModuleUIConfigurationManager as ModuleUIConfigurationManager
with suppress(ImportError):
    from ...dyn.ui.module_ui_configuration_manager_supplier import ModuleUIConfigurationManagerSupplier as ModuleUIConfigurationManagerSupplier
with suppress(ImportError):
    from ...dyn.ui.module_window_state_configuration import ModuleWindowStateConfiguration as ModuleWindowStateConfiguration
with suppress(ImportError):
    from ...dyn.ui.ui_category_description import UICategoryDescription as UICategoryDescription
with suppress(ImportError):
    from ...dyn.ui.ui_configuration_manager import UIConfigurationManager as UIConfigurationManager
with suppress(ImportError):
    from ...dyn.ui.ui_element import UIElement as UIElement
with suppress(ImportError):
    from ...dyn.ui.ui_element_factory import UIElementFactory as UIElementFactory
with suppress(ImportError):
    from ...dyn.ui.ui_element_factory_manager import UIElementFactoryManager as UIElementFactoryManager
with suppress(ImportError):
    from ...dyn.ui.ui_element_settings import UIElementSettings as UIElementSettings
with suppress(ImportError):
    from ...dyn.ui.ui_element_type import UIElementType as UIElementType
with suppress(ImportError):
    from ...dyn.ui.ui_element_type import UIElementTypeEnum as UIElementTypeEnum
with suppress(ImportError):
    from ...dyn.ui.window_content_factory import WindowContentFactory as WindowContentFactory
with suppress(ImportError):
    from ...dyn.ui.window_content_factory_manager import WindowContentFactoryManager as WindowContentFactoryManager
with suppress(ImportError):
    from ...dyn.ui.window_state_configuration import WindowStateConfiguration as WindowStateConfiguration
with suppress(ImportError):
    from ...dyn.ui.x_accelerator_configuration import XAcceleratorConfiguration as XAcceleratorConfiguration
with suppress(ImportError):
    from ...dyn.ui.x_context_change_event_listener import XContextChangeEventListener as XContextChangeEventListener
with suppress(ImportError):
    from ...dyn.ui.x_context_change_event_multiplexer import XContextChangeEventMultiplexer as XContextChangeEventMultiplexer
with suppress(ImportError):
    from ...dyn.ui.x_context_menu_interception import XContextMenuInterception as XContextMenuInterception
with suppress(ImportError):
    from ...dyn.ui.x_context_menu_interceptor import XContextMenuInterceptor as XContextMenuInterceptor
with suppress(ImportError):
    from ...dyn.ui.x_deck import XDeck as XDeck
with suppress(ImportError):
    from ...dyn.ui.x_decks import XDecks as XDecks
with suppress(ImportError):
    from ...dyn.ui.x_docking_area_acceptor import XDockingAreaAcceptor as XDockingAreaAcceptor
with suppress(ImportError):
    from ...dyn.ui.x_image_manager import XImageManager as XImageManager
with suppress(ImportError):
    from ...dyn.ui.x_module_ui_configuration_manager import XModuleUIConfigurationManager as XModuleUIConfigurationManager
with suppress(ImportError):
    from ...dyn.ui.x_module_ui_configuration_manager2 import XModuleUIConfigurationManager2 as XModuleUIConfigurationManager2
with suppress(ImportError):
    from ...dyn.ui.x_module_ui_configuration_manager_supplier import XModuleUIConfigurationManagerSupplier as XModuleUIConfigurationManagerSupplier
with suppress(ImportError):
    from ...dyn.ui.x_panel import XPanel as XPanel
with suppress(ImportError):
    from ...dyn.ui.x_panels import XPanels as XPanels
with suppress(ImportError):
    from ...dyn.ui.x_sidebar import XSidebar as XSidebar
with suppress(ImportError):
    from ...dyn.ui.x_sidebar_panel import XSidebarPanel as XSidebarPanel
with suppress(ImportError):
    from ...dyn.ui.x_sidebar_provider import XSidebarProvider as XSidebarProvider
with suppress(ImportError):
    from ...dyn.ui.x_statusbar_item import XStatusbarItem as XStatusbarItem
with suppress(ImportError):
    from ...dyn.ui.x_tool_panel import XToolPanel as XToolPanel
with suppress(ImportError):
    from ...dyn.ui.xui_configuration import XUIConfiguration as XUIConfiguration
with suppress(ImportError):
    from ...dyn.ui.xui_configuration_listener import XUIConfigurationListener as XUIConfigurationListener
with suppress(ImportError):
    from ...dyn.ui.xui_configuration_manager import XUIConfigurationManager as XUIConfigurationManager
with suppress(ImportError):
    from ...dyn.ui.xui_configuration_manager2 import XUIConfigurationManager2 as XUIConfigurationManager2
with suppress(ImportError):
    from ...dyn.ui.xui_configuration_manager_supplier import XUIConfigurationManagerSupplier as XUIConfigurationManagerSupplier
with suppress(ImportError):
    from ...dyn.ui.xui_configuration_persistence import XUIConfigurationPersistence as XUIConfigurationPersistence
with suppress(ImportError):
    from ...dyn.ui.xui_configuration_storage import XUIConfigurationStorage as XUIConfigurationStorage
with suppress(ImportError):
    from ...dyn.ui.xui_element import XUIElement as XUIElement
with suppress(ImportError):
    from ...dyn.ui.xui_element_factory import XUIElementFactory as XUIElementFactory
with suppress(ImportError):
    from ...dyn.ui.xui_element_factory_manager import XUIElementFactoryManager as XUIElementFactoryManager
with suppress(ImportError):
    from ...dyn.ui.xui_element_factory_registration import XUIElementFactoryRegistration as XUIElementFactoryRegistration
with suppress(ImportError):
    from ...dyn.ui.xui_element_settings import XUIElementSettings as XUIElementSettings
with suppress(ImportError):
    from ...dyn.ui.xui_function_listener import XUIFunctionListener as XUIFunctionListener
with suppress(ImportError):
    from ...dyn.ui.x_update_model import XUpdateModel as XUpdateModel
with suppress(ImportError):
    from ...dyn.ui.the_module_ui_configuration_manager_supplier import theModuleUIConfigurationManagerSupplier as theModuleUIConfigurationManagerSupplier
with suppress(ImportError):
    from ...dyn.ui.the_ui_category_description import theUICategoryDescription as theUICategoryDescription
with suppress(ImportError):
    from ...dyn.ui.the_ui_element_factory_manager import theUIElementFactoryManager as theUIElementFactoryManager
with suppress(ImportError):
    from ...dyn.ui.the_window_content_factory_manager import theWindowContentFactoryManager as theWindowContentFactoryManager
with suppress(ImportError):
    from ...dyn.ui.the_window_state_configuration import theWindowStateConfiguration as theWindowStateConfiguration



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.lang
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .event_object import EventObject as EventObject_a3d70b03

class XEventListener(XInterface_8f010a43):
    """
    base interface for all event listeners interfaces.

    See Also:
        `API XEventListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1lang_1_1XEventListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.XEventListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.lang.XEventListener'

    @abstractmethod
    def disposing(self, Source: EventObject_a3d70b03) -> None:
        """
        gets called when the broadcaster is about to be disposed.
        
        All listeners and all other objects, which reference the broadcaster should release the reference to the source. No method should be invoked anymore on this object ( including XComponent.removeEventListener() ).
        
        This method is called for every listener registration of derived listener interfaced, not only for registrations at XComponent.
        """
        ...

__all__ = ['XEventListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractproperty
from ..document.x_document_sub_storage_supplier import XDocumentSubStorageSupplier as XDocumentSubStorageSupplier_da021351
from .x_form_documents_supplier import XFormDocumentsSupplier as XFormDocumentsSupplier_27dc0f33
from .x_report_documents_supplier import XReportDocumentsSupplier as XReportDocumentsSupplier_490a101b
if typing.TYPE_CHECKING:
    from ..sdbc.x_data_source import XDataSource as XDataSource_a2990ae7

class XOfficeDatabaseDocument(XDocumentSubStorageSupplier_da021351, XFormDocumentsSupplier_27dc0f33, XReportDocumentsSupplier_490a101b):
    """
    simplifies the accessing of data sources, and it's corresponding database document and forms, and reports.

    See Also:
        `API XOfficeDatabaseDocument <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XOfficeDatabaseDocument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XOfficeDatabaseDocument'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XOfficeDatabaseDocument'

    @abstractproperty
    def DataSource(self) -> XDataSource_a2990ae7:
        """
        provides access to the one and only DataSource associated with this document
        """
        ...


__all__ = ['XOfficeDatabaseDocument']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.lang


class SystemDependent(object):
    """
    Const Class

    These constants are used to specify systems which depend on return values.
    
    You should avoid system-dependent methods if possible.
    
    The Symbols are now prepended with SYSTEM_ thus we avoid collisions with system headers.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API SystemDependent <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1lang_1_1SystemDependent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.SystemDependent'
    __ooo_type_name__: str = 'const'

    SYSTEM_WIN32 = 1
    """
    The called interface method returns a value specified for Windows.
    
    These are Windows XP or higher.
    """
    SYSTEM_WIN16 = 2
    """
    The called interface method returns a value specified for 16-bit Windows.
    
    This is Windows 3.11.
    """
    SYSTEM_JAVA = 3
    """
    The called interface method returns a value specified for Java.
    
    These are JRE 1.1, JRE 1.2, JDK 1.1, JDK 1.2 or higher.
    
    The return should be a handle to a Java object locked with the call JavaEnvironment->NewGlobalRef( ... ) by the callee.
    """
    SYSTEM_OS2 = 4
    """
    The called interface method returns a value specified for OS/2.
    """
    SYSTEM_MAC = 5
    """
    The called interface method returns a value specified for macOS.
    """
    SYSTEM_XWINDOW = 6
    """
    The called interface method returns a value specified for the X Window System.
    """
    SYSTEM_IOS = 7
    """
    The called interface method returns a value specified for iOS.
    """
    SYSTEM_ANDROID = 8
    """
    The called interface method returns a value specified for Android.
    """

__all__ = ['SystemDependent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text.textfield
from __future__ import annotations
from abc import abstractproperty
from ...container.x_child import XChild as XChild_a6390b07
from ...container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ...rdf.x_metadatable import XMetadatable as XMetadatable_a3000af0
from ..text_field import TextField as TextField_90260a56
from ..x_text import XText as XText_690408ca

class MetadataField(TextField_90260a56, XChild_a6390b07, XEnumerationAccess_4bac0ffc, XMetadatable_a3000af0, XText_690408ca):
    """
    Service Class

    is a com.sun.star.text.TextField whose content is specified by RDF metadata.
    
    **since**
    
        OOo 3.2

    See Also:
        `API MetadataField <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1MetadataField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text.textfield'
    __ooo_full_ns__: str = 'com.sun.star.text.textfield.MetadataField'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsFixedLanguage(self) -> bool:
        """
        determines whether changes in language attributes at the position of the text field also change the number format as appropriate for this language.
        """
        ...

    @abstractproperty
    def NumberFormat(self) -> int:
        """
        this is the number format for this field.
        """
        ...


__all__ = ['MetadataField']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..document.x_event_broadcaster import XEventBroadcaster as XEventBroadcaster_2b120f2b
from .x_classified_object import XClassifiedObject as XClassifiedObject_fa3b0dab
from .x_component_supplier import XComponentSupplier as XComponentSupplier_adb0e64
from .x_state_change_broadcaster import XStateChangeBroadcaster as XStateChangeBroadcaster_539f100e
from .x_visual_object import XVisualObject as XVisualObject_c6c80c28
from ..util.x_closeable import XCloseable as XCloseable_99ee0aa8
if typing.TYPE_CHECKING:
    from .verb_descriptor import VerbDescriptor as VerbDescriptor_d3680cb3
    from .x_embedded_client import XEmbeddedClient as XEmbeddedClient_ddea0cc6

class XEmbeddedObject(XEventBroadcaster_2b120f2b, XClassifiedObject_fa3b0dab, XComponentSupplier_adb0e64, XStateChangeBroadcaster_539f100e, XVisualObject_c6c80c28, XCloseable_99ee0aa8):
    """
    represents common functionality for embedded objects.

    See Also:
        `API XEmbeddedObject <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XEmbeddedObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XEmbeddedObject'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XEmbeddedObject'

    @abstractmethod
    def changeState(self, nNewState: int) -> None:
        """
        changes the state of the object to the requested one.

        Raises:
            com.sun.star.embed.UnreachableStateException: ``UnreachableStateException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def doVerb(self, nVerbID: int) -> None:
        """
        lets object perform an action referenced by nVerbID.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.embed.UnreachableStateException: ``UnreachableStateException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def getClientSite(self) -> XEmbeddedClient_ddea0cc6:
        """
        provides access to the internal link to the container client.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def getCurrentState(self) -> int:
        """
        returns the current state of the object.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def getReachableStates(self) -> uno.ByteSequence:
        """
        returns supported states for the object.

        Raises:
            com.sun.star.embed.NeedsRunningStateException: ``NeedsRunningStateException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def getStatus(self, nAspect: int) -> int:
        """
        retrieves the status of the object.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def getSupportedVerbs(self) -> typing.Tuple[VerbDescriptor_d3680cb3, ...]:
        """
        returns supported verbs for the object.

        Raises:
            com.sun.star.embed.NeedsRunningStateException: ``NeedsRunningStateException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def setClientSite(self, xClient: XEmbeddedClient_ddea0cc6) -> None:
        """
        sets a connection to the container's client.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def setContainerName(self, sName: str) -> None:
        """
        provides object with the name of container document.
        """
        ...
    @abstractmethod
    def setUpdateMode(self, nMode: int) -> None:
        """
        specifies how often the object's representation should be updated.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...
    @abstractmethod
    def update(self) -> None:
        """
        updates object's representations.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XEmbeddedObject']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb.application
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class DatabaseObjectContainer(metaclass=UnoConstMeta, type_name="com.sun.star.sdb.application.DatabaseObjectContainer", name_space="com.sun.star.sdb.application"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sdb.application.DatabaseObjectContainer``"""
        pass

    class DatabaseObjectContainerEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sdb.application.DatabaseObjectContainer", name_space="com.sun.star.sdb.application"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sdb.application.DatabaseObjectContainer`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sdb.application import DatabaseObjectContainer as DatabaseObjectContainer
    else:
        # keep document generators happy
        from ....lo.sdb.application.database_object_container import DatabaseObjectContainer as DatabaseObjectContainer

    class DatabaseObjectContainerEnum(IntEnum):
        """
        Enum of Const Class DatabaseObjectContainer

        denotes different types of (maybe virtual) containers of database objects
        
        In the database application of OpenOffice.org, database objects (such as tables, queries, forms, reports) can be organized in folders. This hierarchy can be imposed externally, or internally.
        
        For example, when you connect to a database which supports catalogs and/or schemas, then those impose a natural order on the tables, in that a catalog or a schema is a folder of tables.
        
        On the other hand, for forms and reports, OpenOffice.org Base itself allows the user to create folders to organize the documents - in this case, the hierarchy is defined in the database document itself.
        
        **since**
        
            OOo 3.0
        """
        TABLES = DatabaseObjectContainer.TABLES
        """
        denotes the virtual folder containing all tables of a database, in a context where such a folder is displayed to the user.
        """
        QUERIES = DatabaseObjectContainer.QUERIES
        """
        denotes the virtual folder containing all queries of a database, in a context where such a folder is displayed to the user.
        """
        FORMS = DatabaseObjectContainer.FORMS
        """
        denotes the virtual folder containing all forms of a database document, in a context where such a folder is displayed to the user.
        """
        REPORTS = DatabaseObjectContainer.REPORTS
        """
        denotes the virtual folder containing all reports of a database, in a context where such a folder is displayed to the user.
        """
        DATA_SOURCE = DatabaseObjectContainer.DATA_SOURCE
        """
        denotes the data source itself, which effectively is the root container for all other kind of database objects, including other container types.
        """
        CATALOG = DatabaseObjectContainer.CATALOG
        """
        denotes a catalog in a database which supports catalogs
        """
        SCHEMA = DatabaseObjectContainer.SCHEMA
        """
        denotes a schema in a database which supports schemas
        """
        FORMS_FOLDER = DatabaseObjectContainer.FORMS_FOLDER
        """
        denotes a folder which is used to organize forms in a database document
        """
        REPORTS_FOLDER = DatabaseObjectContainer.REPORTS_FOLDER
        """
        denotes a folder which is used to organize reports in a database document
        """

__all__ = ['DatabaseObjectContainer', 'DatabaseObjectContainerEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_status_listener import XStatusListener as XStatusListener_e2740d35
    from ..util.url import URL as URL_57ad07b9

class XDispatch(XInterface_8f010a43):
    """
    serves state information of objects which can be connected to controls (e.g.
    
    toolbox controls).
    
    Each state change is to be broadcasted to all registered status listeners. The first notification should be performed synchronously from XDispatch.addStatusListener(); if not, controls may flicker. State listener must be aware of this synchronous notification.
    
    The state consists of enabled/disabled and a short descriptive text of the function (e.g. \"undo insert character\"). It is to be broadcasted whenever this state changes or the control should re-get the value for the URL it is connected to. Additionally, a context-switch-event is to be broadcasted whenever the object may be out of scope, to force the state listener to requery the XDispatch.

    See Also:
        `API XDispatch <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatch.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XDispatch'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XDispatch'

    @abstractmethod
    def addStatusListener(self, Control: XStatusListener_e2740d35, URL: URL_57ad07b9) -> None:
        """
        registers a listener of a control for a specific URL at this object to receive status events.
        
        It is only allowed to register URLs for which this XDispatch was explicitly queried. Additional arguments (\"#...\" or \"?...\") will be ignored.
        
        Note: Notifications can't be guaranteed! This will be a part of interface XNotifyingDispatch.
        """
        ...
    @abstractmethod
    def dispatch(self, URL: URL_57ad07b9, Arguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        dispatches (executes) a URL
        
        It is only allowed to dispatch URLs for which this XDispatch was explicitly queried. Additional arguments (\"'#...\" or \"?...\") are allowed.
        
        Controlling synchronous or asynchronous mode happens via readonly boolean Flag SynchronMode
        
        By default, and absent any arguments, \"SynchronMode\" is considered FALSE and the execution is performed asynchronously (i.e. dispatch() returns immediately, and the action is performed in the background). But when set to TRUE, dispatch() processes the request synchronously
        
        some code for a click-handler (Java)
        """
        ...
    @abstractmethod
    def removeStatusListener(self, Control: XStatusListener_e2740d35, URL: URL_57ad07b9) -> None:
        """
        unregisters a listener from a control.
        """
        ...

__all__ = ['XDispatch']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.grid
from __future__ import annotations
import typing
import uno
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_grid_selection_listener import XGridSelectionListener as XGridSelectionListener_759e10f2

class XGridRowSelection(ABC):
    """
    This interfaces provides access to the selection of row for UnoControlGrid.
    
    **since**
    
        LibreOffice 3.4

    See Also:
        `API XGridRowSelection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridRowSelection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.grid'
    __ooo_full_ns__: str = 'com.sun.star.awt.grid.XGridRowSelection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.grid.XGridRowSelection'

    @abstractmethod
    def addSelectionListener(self, listener: XGridSelectionListener_759e10f2) -> None:
        """
        Adds a listener for the GridSelectionEvent posted after the grid changes.
        """
        ...
    @abstractmethod
    def deselectAllRows(self) -> None:
        """
        Deselects all selected rows.
        """
        ...
    @abstractmethod
    def deselectRow(self, RowIndex: int) -> None:
        """
        removes the selection for a given row

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getSelectedRows(self) -> uno.ByteSequence:
        """
        Returns the indices of all selected rows.
        """
        ...
    @abstractmethod
    def hasSelectedRows(self) -> bool:
        """
        Returns whether rows are selected.
        """
        ...
    @abstractmethod
    def isRowSelected(self, RowIndex: int) -> bool:
        """
        Returns whether a specific row is selected.
        """
        ...
    @abstractmethod
    def removeSelectionListener(self, listener: XGridSelectionListener_759e10f2) -> None:
        """
        Removes a listener previously added with addSelectionListener().
        """
        ...
    @abstractmethod
    def selectAllRows(self) -> None:
        """
        Selects all rows.
        """
        ...
    @abstractmethod
    def selectRow(self, RowIndex: int) -> None:
        """
        selects a given row

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...

__all__ = ['XGridRowSelection']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.control
from __future__ import annotations
from ...awt.uno_control_button import UnoControlButton as UnoControlButton_d5e30ce3
from ..x_approve_action_broadcaster import XApproveActionBroadcaster as XApproveActionBroadcaster_693d10b9

class CommandButton(UnoControlButton_d5e30ce3, XApproveActionBroadcaster_693d10b9):
    """
    Service Class

    describes a button control.
    
    The model of the control has to support the com.sun.star.form.component.CommandButton service.
    
    The control is clickable, the action taken upon clicking depends on the settings of the model the control belongs to.

    See Also:
        `API CommandButton <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1control_1_1CommandButton.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.control'
    __ooo_full_ns__: str = 'com.sun.star.form.control.CommandButton'
    __ooo_type_name__: str = 'service'


__all__ = ['CommandButton']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class URL(object):
    """
    Struct Class

    represents the structure of a Uniform Resource Locator.
    
    If the structure represents a valid URL or not depends on prior usage of the functions of XURLTransformer. Only after one of the functions returned TRUE this can be assumed.It is not necessary to set all of the fields; either URL.Complete or (some of) the others are set. Additionally, most of the other fields, like URL.Host, URL.Port, URL.User, URL.Password, or URL.Mark, are optional.

    See Also:
        `API URL <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1URL.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.URL'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.util.URL'
    """Literal Constant ``com.sun.star.util.URL``"""

    def __init__(self, Complete: typing.Optional[str] = '', Main: typing.Optional[str] = '', Protocol: typing.Optional[str] = '', User: typing.Optional[str] = '', Password: typing.Optional[str] = '', Server: typing.Optional[str] = '', Port: typing.Optional[int] = 0, Path: typing.Optional[str] = '', Name: typing.Optional[str] = '', Arguments: typing.Optional[str] = '', Mark: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Complete (str, optional): Complete value.
            Main (str, optional): Main value.
            Protocol (str, optional): Protocol value.
            User (str, optional): User value.
            Password (str, optional): Password value.
            Server (str, optional): Server value.
            Port (int, optional): Port value.
            Path (str, optional): Path value.
            Name (str, optional): Name value.
            Arguments (str, optional): Arguments value.
            Mark (str, optional): Mark value.
        """
        super().__init__()

        if isinstance(Complete, URL):
            oth: URL = Complete
            self.Complete = oth.Complete
            self.Main = oth.Main
            self.Protocol = oth.Protocol
            self.User = oth.User
            self.Password = oth.Password
            self.Server = oth.Server
            self.Port = oth.Port
            self.Path = oth.Path
            self.Name = oth.Name
            self.Arguments = oth.Arguments
            self.Mark = oth.Mark
            return

        kargs = {
            "Complete": Complete,
            "Main": Main,
            "Protocol": Protocol,
            "User": User,
            "Password": Password,
            "Server": Server,
            "Port": Port,
            "Path": Path,
            "Name": Name,
            "Arguments": Arguments,
            "Mark": Mark,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._complete = kwargs["Complete"]
        self._main = kwargs["Main"]
        self._protocol = kwargs["Protocol"]
        self._user = kwargs["User"]
        self._password = kwargs["Password"]
        self._server = kwargs["Server"]
        self._port = kwargs["Port"]
        self._path = kwargs["Path"]
        self._name = kwargs["Name"]
        self._arguments = kwargs["Arguments"]
        self._mark = kwargs["Mark"]


    @property
    def Complete(self) -> str:
        """
        contains the string representation of the complete URL, for example, http://www.sun.de:8080/pub/test/foo.txt?a=b#xyz
        
        It is used as a central input/output or input parameter for the interfaces of XURLTransformer. The usage of one of the XURLTransformer function is mandatory to validate the URL. It cannot be assumed that URL.Complete represents always a valid URL!
        """
        return self._complete

    @Complete.setter
    def Complete(self, value: str) -> None:
        self._complete = value

    @property
    def Main(self) -> str:
        """
        contains the URL without a mark and without arguments, for example, http://www.sun.de:8080/pub/test/foo.txt
        """
        return self._main

    @Main.setter
    def Main(self, value: str) -> None:
        self._main = value

    @property
    def Protocol(self) -> str:
        """
        contains the protocol (scheme) of the URL, for example, \"http\"
        """
        return self._protocol

    @Protocol.setter
    def Protocol(self, value: str) -> None:
        self._protocol = value

    @property
    def User(self) -> str:
        """
        contains the user-identifier of the URL, for example, \"me\"
        """
        return self._user

    @User.setter
    def User(self, value: str) -> None:
        self._user = value

    @property
    def Password(self) -> str:
        """
        contains the users password of the URL, for example, \"pass\"
        """
        return self._password

    @Password.setter
    def Password(self, value: str) -> None:
        self._password = value

    @property
    def Server(self) -> str:
        """
        contains the server part of the URL, for example, \"www.sun.de\"
        """
        return self._server

    @Server.setter
    def Server(self, value: str) -> None:
        self._server = value

    @property
    def Port(self) -> int:
        """
        contains the port at the server of the URL, for example, \"8080\"
        """
        return self._port

    @Port.setter
    def Port(self, value: int) -> None:
        self._port = value

    @property
    def Path(self) -> str:
        """
        contains all segments but the last one of the hierarchical path of the URL, for example, \"/pub/test/\"
        """
        return self._path

    @Path.setter
    def Path(self, value: str) -> None:
        self._path = value

    @property
    def Name(self) -> str:
        """
        contains the last segment of the hierarchical path of the URL, for the above example, \"foo.txt\"
        
        Attention:A service implementing the XURLTransformer interface will normally not detect if the last segment is a folder or a file. So it is possible that the last segment describes a folder. If you want to be sure that a file URL that references a folder will be correctly put into the URL fields you should append a \"/\" at the end of the hierarchical path.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def Arguments(self) -> str:
        """
        contains the arguments part of the URL, for example, \"a=b\"
        """
        return self._arguments

    @Arguments.setter
    def Arguments(self, value: str) -> None:
        self._arguments = value

    @property
    def Mark(self) -> str:
        """
        contains the mark part of the URL, for example, \"xyz\"
        """
        return self._mark

    @Mark.setter
    def Mark(self, value: str) -> None:
        self._mark = value


__all__ = ['URL']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..beans.x_property_state import XPropertyState as XPropertyState_d55c0ccf
from ..beans.x_tolerant_multi_property_set import XTolerantMultiPropertySet as XTolerantMultiPropertySet_7bd4114e
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from ..style.paragraph_properties_asian import ParagraphPropertiesAsian as ParagraphPropertiesAsian_6e8c10e8
from ..style.paragraph_properties_complex import ParagraphPropertiesComplex as ParagraphPropertiesComplex_91de11d4
from .text_content import TextContent as TextContent_a6810b4d
from .text_table import TextTable as TextTable_90440a5a

class Paragraph(TextTable_90440a5a, TextContent_a6810b4d, CharacterProperties_1d4f0ef3, CharacterPropertiesComplex_90ca11cb, CharacterPropertiesAsian_6d8a10df, ParagraphProperties_1e240efc, ParagraphPropertiesComplex_91de11d4, ParagraphPropertiesAsian_6e8c10e8, XPropertySet_bc180bfa, XPropertyState_d55c0ccf, XEnumerationAccess_4bac0ffc, XTolerantMultiPropertySet_7bd4114e):
    """
    Service Class

    is a piece of text which can take its own paragraph-specific attributes (technically, properties).
    
    **since**
    
        OOo 2.0

    See Also:
        `API Paragraph <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1Paragraph.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.Paragraph'
    __ooo_type_name__: str = 'service'


__all__ = ['Paragraph']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
from abc import abstractmethod
from .x_bitmap import XBitmap as XBitmap_b1b70b7b

class XVolatileBitmap(XBitmap_b1b70b7b):
    """
    This is a specialized interface to a volatile bitmap (which can become invalid at any point in time).

    See Also:
        `API XVolatileBitmap <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XVolatileBitmap.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XVolatileBitmap'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XVolatileBitmap'

    @abstractmethod
    def isValid(self) -> bool:
        """
        Query whether this volatile bitmap still has valid content.
        
        As the video RAM allocated to this bitmap can be reclaimed at any time, a return value of true here does not imply that the next draw operation with this bitmap will succeed. Instead, the exception VolatileContentDestroyed might then be thrown, if lost bitmap data is accessed.
        """
        ...

__all__ = ['XVolatileBitmap']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .dispatch_descriptor import DispatchDescriptor as DispatchDescriptor_b280e62
    from .x_dispatch import XDispatch as XDispatch_98ff0a9b
    from ..util.url import URL as URL_57ad07b9

class XDispatchProvider(XInterface_8f010a43):
    """
    provides XDispatch interfaces for certain functions which are useful at the UI.

    See Also:
        `API XDispatchProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatchProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XDispatchProvider'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XDispatchProvider'

    @abstractmethod
    def queryDispatch(self, URL: URL_57ad07b9, TargetFrameName: str, SearchFlags: int) -> XDispatch_98ff0a9b:
        """
        searches for an XDispatch for the specified URL within the specified target frame.
        """
        ...
    @abstractmethod
    def queryDispatches(self, Requests: typing.Tuple[DispatchDescriptor_b280e62, ...]) -> typing.Tuple[XDispatch_98ff0a9b, ...]:
        """
        actually this method is redundant to XDispatchProvider.queryDispatch() to avoid multiple remote calls.
        
        It's not allowed to pack it - because every request must match to its real result. Means: don't delete NULL entries inside this list.
        """
        ...

__all__ = ['XDispatchProvider']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_connection import XConnection as XConnection_a36a0b0c

class XDriverManager(XInterface_8f010a43):
    """
    is the basic interface for managing a set of SDBC drivers.
    
    When the method com.sun.star.sdbc.XDriverManager.getConnection() is called, the DriverManager will attempt to locate a suitable driver.

    See Also:
        `API XDriverManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDriverManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XDriverManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XDriverManager'

    @abstractmethod
    def getConnection(self, url: str) -> XConnection_a36a0b0c:
        """
        attempts to establish a connection to the given database URL.
        
        The DriverManager attempts to select an appropriate driver from the set of registered JDBC/SDBC drivers.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getConnectionWithInfo(self, url: str, info: typing.Tuple[PropertyValue_c9610c73, ...]) -> XConnection_a36a0b0c:
        """
        attempts to establish a connection to the given database URL.
        
        The DriverManager attempts to select an appropriate driver from the set of registered JDBC/SDBC drivers.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getLoginTimeout(self) -> int:
        """
        gets the maximum time in seconds that a driver can wait when attempting to login to a database.
        """
        ...
    @abstractmethod
    def setLoginTimeout(self, seconds: int) -> None:
        """
        sets the maximum time in seconds that a driver will wait while attempting to connect to a database.
        """
        ...

__all__ = ['XDriverManager']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.graphic.emf_tools import EmfTools as EmfTools
with suppress(ImportError):
    from ...dyn.graphic.graphic import Graphic as Graphic
with suppress(ImportError):
    from ...dyn.graphic.graphic_color_mode import GraphicColorMode as GraphicColorMode
with suppress(ImportError):
    from ...dyn.graphic.graphic_color_mode import GraphicColorModeEnum as GraphicColorModeEnum
with suppress(ImportError):
    from ...dyn.graphic.graphic_descriptor import GraphicDescriptor as GraphicDescriptor
with suppress(ImportError):
    from ...dyn.graphic.graphic_mapper import GraphicMapper as GraphicMapper
with suppress(ImportError):
    from ...dyn.graphic.graphic_object import GraphicObject as GraphicObject
with suppress(ImportError):
    from ...dyn.graphic.graphic_provider import GraphicProvider as GraphicProvider
with suppress(ImportError):
    from ...dyn.graphic.graphic_rasterizer import GraphicRasterizer as GraphicRasterizer
with suppress(ImportError):
    from ...dyn.graphic.graphic_renderer_vcl import GraphicRendererVCL as GraphicRendererVCL
with suppress(ImportError):
    from ...dyn.graphic.graphic_type import GraphicType as GraphicType
with suppress(ImportError):
    from ...dyn.graphic.graphic_type import GraphicTypeEnum as GraphicTypeEnum
with suppress(ImportError):
    from ...dyn.graphic.media_properties import MediaProperties as MediaProperties
with suppress(ImportError):
    from ...dyn.graphic.pdf_tools import PdfTools as PdfTools
with suppress(ImportError):
    from ...dyn.graphic.primitive2_d_tools import Primitive2DTools as Primitive2DTools
with suppress(ImportError):
    from ...dyn.graphic.primitive_factory2_d import PrimitiveFactory2D as PrimitiveFactory2D
with suppress(ImportError):
    from ...dyn.graphic.svg_tools import SvgTools as SvgTools
with suppress(ImportError):
    from ...dyn.graphic.x_emf_parser import XEmfParser as XEmfParser
with suppress(ImportError):
    from ...dyn.graphic.x_graphic import XGraphic as XGraphic
with suppress(ImportError):
    from ...dyn.graphic.x_graphic_mapper import XGraphicMapper as XGraphicMapper
with suppress(ImportError):
    from ...dyn.graphic.x_graphic_object import XGraphicObject as XGraphicObject
with suppress(ImportError):
    from ...dyn.graphic.x_graphic_provider import XGraphicProvider as XGraphicProvider
with suppress(ImportError):
    from ...dyn.graphic.x_graphic_provider2 import XGraphicProvider2 as XGraphicProvider2
with suppress(ImportError):
    from ...dyn.graphic.x_graphic_rasterizer import XGraphicRasterizer as XGraphicRasterizer
with suppress(ImportError):
    from ...dyn.graphic.x_graphic_renderer import XGraphicRenderer as XGraphicRenderer
with suppress(ImportError):
    from ...dyn.graphic.x_graphic_transformer import XGraphicTransformer as XGraphicTransformer
with suppress(ImportError):
    from ...dyn.graphic.x_pdf_decomposer import XPdfDecomposer as XPdfDecomposer
with suppress(ImportError):
    from ...dyn.graphic.x_primitive2_d import XPrimitive2D as XPrimitive2D
with suppress(ImportError):
    from ...dyn.graphic.x_primitive2_d_renderer import XPrimitive2DRenderer as XPrimitive2DRenderer
with suppress(ImportError):
    from ...dyn.graphic.x_primitive3_d import XPrimitive3D as XPrimitive3D
with suppress(ImportError):
    from ...dyn.graphic.x_primitive_factory2_d import XPrimitiveFactory2D as XPrimitiveFactory2D
with suppress(ImportError):
    from ...dyn.graphic.x_svg_parser import XSvgParser as XSvgParser



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XFunctionDescriptions(XIndexAccess_f0910d6d):
    """
    provides access to the property sequence of a function description via function index or identifier.
    
    The container access methods return a sequence of com.sun.star.beans.PropertyValue structs. The properties contained in the sequence are collected in the service FunctionDescription.

    See Also:
        `API XFunctionDescriptions <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XFunctionDescriptions.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XFunctionDescriptions'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XFunctionDescriptions'

    @abstractmethod
    def getById(self, nId: int) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        finds a function description by the identifier of the function.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XFunctionDescriptions']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.task
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .classified_interaction_request import ClassifiedInteractionRequest as ClassifiedInteractionRequest_9f72121b
from ..uno.x_interface import XInterface as XInterface_8f010a43
from .interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7
from ..embed.x_storage import XStorage as XStorage_8e460a32
from ..security.document_signature_information import DocumentSignatureInformation as DocumentSignatureInformation_f36c13f7

class DocumentMacroConfirmationRequest(ClassifiedInteractionRequest_9f72121b):
    """
    Exception Class

    describes the request to approve or deny the execution of macros contained in a document.

    See Also:
        `API DocumentMacroConfirmationRequest <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1task_1_1DocumentMacroConfirmationRequest.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.DocumentMacroConfirmationRequest'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.task.DocumentMacroConfirmationRequest'
    __pyunostruct__: str = 'com.sun.star.task.DocumentMacroConfirmationRequest'

    typeName: str = 'com.sun.star.task.DocumentMacroConfirmationRequest'
    """Literal Constant ``com.sun.star.task.DocumentMacroConfirmationRequest``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, Classification: typing.Optional[InteractionClassification_6c4d10e7] = InteractionClassification_6c4d10e7.ERROR, DocumentSignatureInformation: typing.Optional[typing.Tuple[DocumentSignatureInformation_f36c13f7, ...]] = (), DocumentURL: typing.Optional[str] = '', DocumentStorage: typing.Optional[XStorage_8e460a32] = None, DocumentVersion: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            DocumentSignatureInformation (typing.Tuple[DocumentSignatureInformation, ...], optional): DocumentSignatureInformation value.
            DocumentURL (str, optional): DocumentURL value.
            DocumentStorage (XStorage, optional): DocumentStorage value.
            DocumentVersion (str, optional): DocumentVersion value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "Classification": Classification,
            "DocumentSignatureInformation": DocumentSignatureInformation,
            "DocumentURL": DocumentURL,
            "DocumentStorage": DocumentStorage,
            "DocumentVersion": DocumentVersion,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._document_signature_information = kwargs["DocumentSignatureInformation"]
        self._document_url = kwargs["DocumentURL"]
        self._document_storage = kwargs["DocumentStorage"]
        self._document_version = kwargs["DocumentVersion"]
        inst_keys = ('DocumentSignatureInformation', 'DocumentURL', 'DocumentStorage', 'DocumentVersion')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def DocumentSignatureInformation(self) -> typing.Tuple[DocumentSignatureInformation_f36c13f7, ...]:
        """
        contains information about the signatures in the document
        """
        return self._document_signature_information
    
    @DocumentSignatureInformation.setter
    def DocumentSignatureInformation(self, value: typing.Tuple[DocumentSignatureInformation_f36c13f7, ...]) -> None:
        self._document_signature_information = value

    @property
    def DocumentURL(self) -> str:
        """
        specifies the URL of the document which contains macros whose execution should be approved or rejected.
        """
        return self._document_url
    
    @DocumentURL.setter
    def DocumentURL(self, value: str) -> None:
        self._document_url = value

    @property
    def DocumentStorage(self) -> XStorage_8e460a32:
        """
        refers to the storage related to the last committed version of the document.
        
        This storage is necessary e.g. for displaying the existing signatures to the user, to allow him a decision whether or not to trust those signatures and thus the signed macros.
        """
        return self._document_storage
    
    @DocumentStorage.setter
    def DocumentStorage(self, value: XStorage_8e460a32) -> None:
        self._document_storage = value

    @property
    def DocumentVersion(self) -> str:
        """
        contains information about the ODF version of the document
        """
        return self._document_version
    
    @DocumentVersion.setter
    def DocumentVersion(self, value: str) -> None:
        self._document_version = value


__all__ = ['DocumentMacroConfirmationRequest']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.registry.cannot_register_implementation_exception import CannotRegisterImplementationException as CannotRegisterImplementationException
from ...lo.registry.default_registry import DefaultRegistry as DefaultRegistry
from ...lo.registry.implementation_registration import ImplementationRegistration as ImplementationRegistration
from ...lo.registry.invalid_registry_exception import InvalidRegistryException as InvalidRegistryException
from ...lo.registry.invalid_value_exception import InvalidValueException as InvalidValueException
from ...lo.registry.merge_conflict_exception import MergeConflictException as MergeConflictException
from ...lo.registry.nested_registry import NestedRegistry as NestedRegistry
from ...lo.registry.registry_key_type import RegistryKeyType as RegistryKeyType
from ...lo.registry.registry_value_type import RegistryValueType as RegistryValueType
from ...lo.registry.simple_registry import SimpleRegistry as SimpleRegistry
from ...lo.registry.x_implementation_registration import XImplementationRegistration as XImplementationRegistration
from ...lo.registry.x_implementation_registration2 import XImplementationRegistration2 as XImplementationRegistration2
from ...lo.registry.x_registry_key import XRegistryKey as XRegistryKey
from ...lo.registry.x_simple_registry import XSimpleRegistry as XSimpleRegistry



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from ..awt.x_user_input_interception import XUserInputInterception as XUserInputInterception_2a7e0f4f
from ..datatransfer.x_transferable_supplier import XTransferableSupplier as XTransferableSupplier_b602128c
from .x_controller import XController as XController_b00e0b8f
from .x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6
from ..ui.x_context_menu_interception import XContextMenuInterception as XContextMenuInterception_38f90fac
from ..view.x_selection_supplier import XSelectionSupplier as XSelectionSupplier_fed20e15

class Controller(XUserInputInterception_2a7e0f4f, XTransferableSupplier_b602128c, XController_b00e0b8f, XDispatchProvider_fc690de6, XContextMenuInterception_38f90fac, XSelectionSupplier_fed20e15):
    """
    Service Class

    is an abstract service for a component which offers a deeper integration of desktop components than a com.sun.star.awt.XWindow can offer
    
    Such components can be loaded into a Frame inside a Desktop environment. A controller is a richer component then a pure window, but full featured components need a XModel interface too. (see service com.sun.star.document.OfficeDocument for further information)

    See Also:
        `API Controller <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1Controller.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.Controller'
    __ooo_type_name__: str = 'service'


__all__ = ['Controller']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class StringContext(object):
    """
    Struct Class

    Collection of string-related arguments used on all canvas text interfaces.
    
    A possibly much larger string than later rendered is necessary here, because in several languages, glyph selection is context dependent.
    
    **since**
    
        OOo 2.0

    See Also:
        `API StringContext <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1StringContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.StringContext'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.rendering.StringContext'
    """Literal Constant ``com.sun.star.rendering.StringContext``"""

    def __init__(self, Text: typing.Optional[str] = '', StartPosition: typing.Optional[int] = 0, Length: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Text (str, optional): Text value.
            StartPosition (int, optional): StartPosition value.
            Length (int, optional): Length value.
        """
        super().__init__()

        if isinstance(Text, StringContext):
            oth: StringContext = Text
            self.Text = oth.Text
            self.StartPosition = oth.StartPosition
            self.Length = oth.Length
            return

        kargs = {
            "Text": Text,
            "StartPosition": StartPosition,
            "Length": Length,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._text = kwargs["Text"]
        self._start_position = kwargs["StartPosition"]
        self._length = kwargs["Length"]


    @property
    def Text(self) -> str:
        """
        The complete text, from which a subset is selected by the parameters below.
        """
        return self._text

    @Text.setter
    def Text(self, value: str) -> None:
        self._text = value

    @property
    def StartPosition(self) -> int:
        """
        Start position within the string.
        
        The first character has index 0.
        """
        return self._start_position

    @StartPosition.setter
    def StartPosition(self, value: int) -> None:
        self._start_position = value

    @property
    def Length(self) -> int:
        """
        Length of the substring to actually use.
        
        Must be within the range [0,INTMAX].
        """
        return self._length

    @Length.setter
    def Length(self, value: int) -> None:
        self._length = value


__all__ = ['StringContext']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.bridge.oleautomation
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class SCode(object):
    """
    Struct Class

    is the UNO representation of the Automation type SCODE.
    
    A SCODE is used to express errors in Automation. In UNO it could be represented by a long and therefore a typedef from long to a particular error type would do. But a typedef cannot be expressed in all language bindings. In the case where no typedefs are supported the actual type is used. That is, a typedef'd error type would be represented as int in Java. The information that the int is an error type is lost.
    
    When calling Automation objects from UNO the distinction between error type and long is important. Therefore the Scode is declared as struct.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API SCode <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1SCode.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.bridge.oleautomation'
    __ooo_full_ns__: str = 'com.sun.star.bridge.oleautomation.SCode'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.bridge.oleautomation.SCode'
    """Literal Constant ``com.sun.star.bridge.oleautomation.SCode``"""

    def __init__(self, Value: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Value (int, optional): Value value.
        """
        super().__init__()

        if isinstance(Value, SCode):
            oth: SCode = Value
            self.Value = oth.Value
            return

        kargs = {
            "Value": Value,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._value = kwargs["Value"]


    @property
    def Value(self) -> int:
        return self._value

    @Value.setter
    def Value(self, value: int) -> None:
        self._value = value


__all__ = ['SCode']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.security.access_control_exception import AccessControlException as AccessControlException
with suppress(ImportError):
    from ...dyn.security.access_controller import AccessController as AccessController
with suppress(ImportError):
    from ...dyn.security.all_permission import AllPermission as AllPermission
with suppress(ImportError):
    from ...dyn.security.cert_alt_name_entry import CertAltNameEntry as CertAltNameEntry
with suppress(ImportError):
    from ...dyn.security.certificate_characters import CertificateCharacters as CertificateCharacters
with suppress(ImportError):
    from ...dyn.security.certificate_characters import CertificateCharactersEnum as CertificateCharactersEnum
with suppress(ImportError):
    from ...dyn.security.certificate_container import CertificateContainer as CertificateContainer
with suppress(ImportError):
    from ...dyn.security.certificate_container_status import CertificateContainerStatus as CertificateContainerStatus
with suppress(ImportError):
    from ...dyn.security.certificate_exception import CertificateException as CertificateException
with suppress(ImportError):
    from ...dyn.security.certificate_kind import CertificateKind as CertificateKind
with suppress(ImportError):
    from ...dyn.security.certificate_validity import CertificateValidity as CertificateValidity
with suppress(ImportError):
    from ...dyn.security.certificate_validity import CertificateValidityEnum as CertificateValidityEnum
with suppress(ImportError):
    from ...dyn.security.cryptography_exception import CryptographyException as CryptographyException
with suppress(ImportError):
    from ...dyn.security.document_digital_signatures import DocumentDigitalSignatures as DocumentDigitalSignatures
with suppress(ImportError):
    from ...dyn.security.document_signature_information import DocumentSignatureInformation as DocumentSignatureInformation
with suppress(ImportError):
    from ...dyn.security.encryption_exception import EncryptionException as EncryptionException
with suppress(ImportError):
    from ...dyn.security.ext_alt_name_type import ExtAltNameType as ExtAltNameType
with suppress(ImportError):
    from ...dyn.security.key_exception import KeyException as KeyException
with suppress(ImportError):
    from ...dyn.security.key_usage import KeyUsage as KeyUsage
with suppress(ImportError):
    from ...dyn.security.key_usage import KeyUsageEnum as KeyUsageEnum
with suppress(ImportError):
    from ...dyn.security.no_password_exception import NoPasswordException as NoPasswordException
with suppress(ImportError):
    from ...dyn.security.policy import Policy as Policy
with suppress(ImportError):
    from ...dyn.security.runtime_permission import RuntimePermission as RuntimePermission
with suppress(ImportError):
    from ...dyn.security.security_infrastructure_exception import SecurityInfrastructureException as SecurityInfrastructureException
with suppress(ImportError):
    from ...dyn.security.signature_exception import SignatureException as SignatureException
with suppress(ImportError):
    from ...dyn.security.x_access_control_context import XAccessControlContext as XAccessControlContext
with suppress(ImportError):
    from ...dyn.security.x_access_controller import XAccessController as XAccessController
with suppress(ImportError):
    from ...dyn.security.x_action import XAction as XAction
with suppress(ImportError):
    from ...dyn.security.x_certificate import XCertificate as XCertificate
with suppress(ImportError):
    from ...dyn.security.x_certificate_container import XCertificateContainer as XCertificateContainer
with suppress(ImportError):
    from ...dyn.security.x_certificate_extension import XCertificateExtension as XCertificateExtension
with suppress(ImportError):
    from ...dyn.security.x_document_digital_signatures import XDocumentDigitalSignatures as XDocumentDigitalSignatures
with suppress(ImportError):
    from ...dyn.security.x_policy import XPolicy as XPolicy
with suppress(ImportError):
    from ...dyn.security.x_san_extension import XSanExtension as XSanExtension



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XExtendedFilterDetection(XInterface_8f010a43):
    """
    provides a \"deep\" filter detection
    
    A \"deep\" filter detection means looking into the document stream to detect the format of it. Services of type ExtendedTypeDetection must support this interface to be called from generic load mechanism of the office for that.

    See Also:
        `API XExtendedFilterDetection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XExtendedFilterDetection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XExtendedFilterDetection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XExtendedFilterDetection'

    @abstractmethod
    def detect(self, Descriptor: object) -> str:
        """
        controls agreement of a \"flat\" TypeDetection with given URL or arguments
        
        Registered services in configuration, which support this interface for different mime types, will be called automatically to look into the document stream and decide which format it represent. Add the collected information about detected documents in given MediaDescriptor Descriptor. The decision must be returned as any valid type name (which specifies the detected format) or an empty value for unknown formats.
        """
        ...

__all__ = ['XExtendedFilterDetection']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.dom
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class DOMExceptionType(Enum):
    """
    Enum Class

    ENUM DOMExceptionType

    See Also:
        `API DOMExceptionType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#a31e3fb46d584de1cfc4b4c7640a41239>`_
    """
    __ooo_ns__: str = "com.sun.star.xml.dom"
    __ooo_full_ns__: str = "com.sun.star.xml.dom.DOMExceptionType"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.xml.dom.DOMExceptionType"

    DOMSTRING_SIZE_ERR = "DOMSTRING_SIZE_ERR"
    """
    """
    HIERARCHY_REQUEST_ERR = "HIERARCHY_REQUEST_ERR"
    """
    """
    INDEX_SIZE_ERR = "INDEX_SIZE_ERR"
    """
    """
    INUSE_ATTRIBUTE_ERR = "INUSE_ATTRIBUTE_ERR"
    """
    """
    INVALID_ACCESS_ERR = "INVALID_ACCESS_ERR"
    """
    """
    INVALID_CHARACTER_ERR = "INVALID_CHARACTER_ERR"
    """
    """
    INVALID_MODIFICATION_ERR = "INVALID_MODIFICATION_ERR"
    """
    """
    INVALID_STATE_ERR = "INVALID_STATE_ERR"
    """
    """
    NAMESPACE_ERR = "NAMESPACE_ERR"
    """
    """
    NOT_FOUND_ERR = "NOT_FOUND_ERR"
    """
    """
    NOT_SUPPORTED_ERR = "NOT_SUPPORTED_ERR"
    """
    """
    NO_DATA_ALLOWED_ERR = "NO_DATA_ALLOWED_ERR"
    """
    """
    NO_MODIFICATION_ALLOWED_ERR = "NO_MODIFICATION_ALLOWED_ERR"
    """
    """
    SYNTAX_ERR = "SYNTAX_ERR"
    """
    """
    WRONG_DOCUMENT_ERR = "WRONG_DOCUMENT_ERR"
    """
    """

__all__ = ["DOMExceptionType"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class HorizontalAdjust(Enum):
    """
    Enum Class


    See Also:
        `API HorizontalAdjust <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text.html#a8105146481666b39ebbd63a934576b6c>`_
    """
    __ooo_ns__: str = "com.sun.star.text"
    __ooo_full_ns__: str = "com.sun.star.text.HorizontalAdjust"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.text.HorizontalAdjust"

    CENTER = "CENTER"
    """
    the object is adjusted to the center.
    
    centric adjusted.
    """
    LEFT = "LEFT"
    """
    the object is left adjusted.
    
    text flows to the left side of the object.
    
    adjusted to the left.
    """
    RIGHT = "RIGHT"
    """
    the object is right adjusted.
    
    text flows to the right side of the object.
    
    adjusted to the right.
    """

__all__ = ["HorizontalAdjust"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XResultSetMetaData(XInterface_8f010a43):
    """
    can be used to find out about the types and properties of the columns in a ResultSet.

    See Also:
        `API XResultSetMetaData <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XResultSetMetaData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.XResultSetMetaData'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdbc.XResultSetMetaData'

    @abstractmethod
    def getCatalogName(self, column: int) -> str:
        """
        gets a column's table's catalog name.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getColumnCount(self) -> int:
        """
        returns the number of columns in this ResultSet.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getColumnDisplaySize(self, column: int) -> int:
        """
        indicates the column's normal max width in chars.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getColumnLabel(self, column: int) -> str:
        """
        gets the suggested column title for use in printouts and displays.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getColumnName(self, column: int) -> str:
        """
        gets a column's name.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getColumnServiceName(self, column: int) -> str:
        """
        returns the fully-qualified name of the service whose instances are manufactured if the method com.sun.star.sdbc.XResultSet..getObject() is called to retrieve a value from the column.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getColumnType(self, column: int) -> int:
        """
        retrieves a column's SQL type.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getColumnTypeName(self, column: int) -> str:
        """
        retrieves a column's database-specific type name.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getPrecision(self, column: int) -> int:
        """
        gets a column's number of decimal digits.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getScale(self, column: int) -> int:
        """
        gets a column's number of digits to right of the decimal point.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getSchemaName(self, column: int) -> str:
        """
        gets a column's table's schema.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getTableName(self, column: int) -> str:
        """
        gets a column's table name.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isAutoIncrement(self, column: int) -> bool:
        """
        indicates whether the column is automatically numbered, thus read-only.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isCaseSensitive(self, column: int) -> bool:
        """
        indicates whether a column's case matters.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isCurrency(self, column: int) -> bool:
        """
        indicates whether the column is a cash value.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isDefinitelyWritable(self, column: int) -> bool:
        """
        indicates whether a write on the column will definitely succeed.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isNullable(self, column: int) -> int:
        """
        indicates the nullability of values in the designated column.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isReadOnly(self, column: int) -> bool:
        """
        indicates whether a column is definitely not writable.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isSearchable(self, column: int) -> bool:
        """
        indicates whether the column can be used in a where clause.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isSigned(self, column: int) -> bool:
        """
        indicates whether values in the column are signed numbers.

        Raises:
            SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def isWritable(self, column: int) -> bool:
        """
        indicates whether it is possible for a write on the column to succeed.

        Raises:
            SQLException: ``SQLException``
        """
        ...

__all__ = ['XResultSetMetaData']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_string_width import XStringWidth as XStringWidth_b1760b95

class XStringAbbreviation(XInterface_8f010a43):
    """
    Abbreviate arbitrary strings.
    
    It is expected that there will be different implementations of this interface, that each expect strings conforming to a certain structure (e.g., URIs, platform-specific file paths, or newsgroup names). The abbreviation algorithms will then take into account the structural information.

    See Also:
        `API XStringAbbreviation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XStringAbbreviation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XStringAbbreviation'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XStringAbbreviation'

    @abstractmethod
    def abbreviateString(self, xStringWidth: XStringWidth_b1760b95, nWidth: int, aString: str) -> str:
        """
        Abbreviate a string, so that the resulting abbreviated string is not wider than some given width.
        
        The width of a string is an abstract concept here, measured via an XStringWidth interface. Examples are the number of characters in the string (XStringWidth will measure the string's length), or the width in pixel when displayed with a specific font (which XStringWidth would encapsulate).
        """
        ...

__all__ = ['XStringAbbreviation']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb.tools


class CompositionType(object):
    """
    Const Class

    specifies which composition should be used when composing a table name.
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API CompositionType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1CompositionType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb.tools'
    __ooo_full_ns__: str = 'com.sun.star.sdb.tools.CompositionType'
    __ooo_type_name__: str = 'const'

    ForTableDefinitions = 0
    """
    specifies composition of a name to be used in table definitions
    """
    ForIndexDefinitions = 1
    """
    specifies composition of a name to be used in index definitions
    """
    ForDataManipulation = 2
    """
    specifies composition of a name to be used in data manipulation
    """
    ForProcedureCalls = 3
    """
    specifies composition of a name to be used in procedure calls
    """
    ForPrivilegeDefinitions = 4
    """
    specifies composition of a name to be used in privilege definitions
    """
    Complete = 5
    """
    specifies complete composition of a table name, including catalog and schema (if present), disregarding any database support for catalog and schema in any particular statements
    """

__all__ = ['CompositionType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.task
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_interaction_handler2 import XInteractionHandler2 as XInteractionHandler2_1a7b0e83
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924

class InteractionHandler(XInteractionHandler2_1a7b0e83):
    """
    Service Class

    An interaction request handler that lets the user handle requests via GUI dialogs.
    
    The interaction handler service has a number of built-in handlers, responsible for a lot of well known interactions. Additionally, there's a configuration module which allows to configure additional handlers, responsible for arbitrary requests.
    
    The following well-known requests can be dealt with by the built-in handlers:
    
    The requests marked with an asterisk are only handled if (a) their continuations match certain restrictions (see below), and (b) the necessary resource strings are available (this can be exploited by applications that carry only a subset of all resource files with them).
    
    The continuation restrictions are as follows: Let C be the subset of the provided continuations that are of type com.sun.star.task.XInteractionApprove, com.sun.star.task.XInteractionDisapprove, com.sun.star.task.XInteractionRetry, or com.sun.star.task.XInteractionAbort (or of a derived type). All other continuations are ignored for these requests. The request is only handled if the set C is any of the following:
    
    An com.sun.star.ucb.InteractiveAugmentedIOException carries with it a sequence of arguments, which should be com.sun.star.beans.PropertyValues. The following details which properties are interpreted by the interaction handler, depending on the request's com.sun.star.ucb.IOErrorCode:
    
    It is possible to configure additional interaction handlers, to which certain requests can be delegated. The configuration node /org.openoffice.Interaction/InteractionHandlers is evaluated and respected by the InteractionHandler implementation.
    
    A custom interaction handler can declare itself responsible for an arbitrary number of UNO types, specified by full-qualified type name. Also, for each type, it can specify whether it is responsible for only this particular type, or all possibly existent derived types.
    
    Whenever the InteractionHandler encounters a request it cannot fulfill itself, it will examine the configuration, to find a handler implementation for the request, and delegate it to the first matching handler.
    
    If multiple custom interaction handlers declare themselves responsible for the same request type, it is not defined which handler will actually be invoked. Thus, when deploying a custom interaction handler, ensure that the types you specify are general enough to cover all requests you want to handle, but also specific enough to not cover requests which other handlers might be interested in.

    See Also:
        `API InteractionHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1task_1_1InteractionHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.InteractionHandler'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createWithParent(self, parent: XWindow_713b0924) -> None:
        """
        Creates an instance.
        """
        ...
    @abstractmethod
    def createWithParentAndContext(self, parent: XWindow_713b0924, context: str) -> None:
        """
        Creates an instance with an additional context.
        """
        ...

__all__ = ['InteractionHandler']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .get_property_tolerant_result import GetPropertyTolerantResult as GetPropertyTolerantResult_7c4e115e
from .property_state import PropertyState as PropertyState_c97b0c77
import typing


class GetDirectPropertyTolerantResult(GetPropertyTolerantResult_7c4e115e):
    """
    Struct Class

    specifies information being retrieved about a single property.
    
    This type is used for the elements in the sequence returned by com.sun.star.beans.XTolerantMultiPropertySet.GetDirectPropertyTolerantResult.

    See Also:
        `API GetDirectPropertyTolerantResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1GetDirectPropertyTolerantResult.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.GetDirectPropertyTolerantResult'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.beans.GetDirectPropertyTolerantResult'
    """Literal Constant ``com.sun.star.beans.GetDirectPropertyTolerantResult``"""

    def __init__(self, Result: typing.Optional[int] = 0, State: typing.Optional[PropertyState_c97b0c77] = PropertyState_c97b0c77.DIRECT_VALUE, Value: typing.Optional[object] = None, Name: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Result (int, optional): Result value.
            State (PropertyState, optional): State value.
            Value (object, optional): Value value.
            Name (str, optional): Name value.
        """

        if isinstance(Result, GetDirectPropertyTolerantResult):
            oth: GetDirectPropertyTolerantResult = Result
            self.Result = oth.Result
            self.State = oth.State
            self.Value = oth.Value
            self.Name = oth.Name
            return

        kargs = {
            "Result": Result,
            "State": State,
            "Value": Value,
            "Name": Name,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        inst_keys = ('Name',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Name(self) -> str:
        """
        specifies the name of the property.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value


__all__ = ['GetDirectPropertyTolerantResult']
